#[repr(C)]pub struct RandomUaIdent(CustomIdent);Expand description
The ua- that is typically automatically constructed by the user agent.
https://drafts.csswg.org/css-values-5/#valdef-random-ua-ident
Tuple Fields
0: CustomIdentImplementations
Sourceimpl RandomUaIdent
impl RandomUaIdent
fn ua_prefixed(property_id: PropertyIdRef<'_>) -> String
Sourcepub fn from_property(property_id: PropertyIdRef<'_>) -> Self
pub fn from_property(property_id: PropertyIdRef<'_>) -> Self
Builds the ua-PROPERTY ident used to replace property-scoped.
Sourcepub fn from_property_and_index(
property_id: PropertyIdRef<'_>,
index: i32,
) -> Self
pub fn from_property_and_index( property_id: PropertyIdRef<'_>, index: i32, ) -> Self
Builds the ua-PROPERTY-INDEX ident used to replace property-index-scoped,
where index is the 1-based index of this random function among all of the
random functions in the declaration.